@@ -319,7 +319,17 @@ func (coreCmd *CoreCmd) setup(img diskimage.CoreImage, filePathChan <-chan strin
 
 	systemPath := img.System()
 
-	if err := img.SetupBoot(); err != nil {
+	if err := coreCmd.install(systemPath); err != nil {
+		return err
+	}
+
+	// check if we installed an oem snap
+	oem, err := loadOem(systemPath)
+	if err != nil {
+		return err
+	}
+
+	if err := img.SetupBoot(oem); err != nil {
 		return err
 	}
 
@@ -327,10 +337,6 @@ func (coreCmd *CoreCmd) setup(img diskimage.CoreImage, filePathChan <-chan strin
 		return err
 	}
 
-	if err := coreCmd.install(systemPath); err != nil {
-		return err
-	}
-
 	if !coreCmd.Cloud {
 		cloudBaseDir := filepath.Join("var", "lib", "cloud")
 
@@ -494,6 +500,31 @@ func getAuthorizedSshKey() (string, error) {
 	return string(pubKey), err
 }
 
+func loadOem(systemPath string) (oem diskimage.OemDescription, err error) {
+	pkgs, err := filepath.Glob(filepath.Join(systemPath, "/oem/*/*/meta/package.yaml"))
+	if err != nil {
+		return oem, err
+	}
+
+	// checking for len(pkgs) > 2 due to the 'current' symlink
+	if len(pkgs) == 0 {
+		return oem, nil
+	} else if len(pkgs) > 2 || err != nil {
+		return oem, errors.New("too many oem packages installed")
+	}
+
+	f, err := ioutil.ReadFile(pkgs[0])
+	if err != nil {
+		return oem, errors.New("failed to read oem yaml")
+	}
+
+	if err := goyaml.Unmarshal([]byte(f), &oem); err != nil {
+		return oem, errors.New("cannot decode oem yaml")
+	}
+
+	return oem, nil
+}
+
 func extractHWDescription(path string) (hw diskimage.HardwareDescription, err error) {
 	// hack to circumvent https://code.google.com/p/go/issues/detail?id=1435
 	if syscall.Getuid() == 0 {
